@@ -1,5 +1,7 @@
-from .base_objects import BaseObj, Cookware, Ingredient, Quantity, Timing
+from .base_objects import BaseObj, Cookware, Ingredient, Timing
+from .quantity import Quantity
 from .recipe import PREFIXES, Metadata, Recipe, Step
+from .utils import WholeFraction
 
 __all__ = [
     'Recipe',
@@ -11,4 +13,5 @@ __all__ = [
     'Metadata',
     'PREFIXES',
     'BaseObj',
+    'WholeFraction',
 ]
