@@ -1,49 +1,9 @@
 """Base Object for Ingredient, Cookware, and Timing"""
 
 import re
-from decimal import Decimal, InvalidOperation
-from fractions import Fraction
 
-from .const import NOTE_PATTERN, QUANTITY_PATTERN, REVERSE_UNIT_MAPPING, UNIT_MAPPINGS
-
-
-class Quantity:
-    """Quantity Class"""
-
-    def __init__(self, qstr: str):
-        self._raw = qstr
-        self.unit = ''
-        if '%' in qstr:
-            self.amount, self.unit = qstr.split('%')
-            self.unit = self.unit.strip()
-        else:
-            self.amount = qstr
-        self.amount = self.amount.strip()
-
-        # Try storing the quantity as a numeric value
-        try:
-            if '/' in self.amount:
-                self.amount = Fraction(re.sub(r'\s+', '', self.amount))
-            elif '.' in self.amount:
-                self.amount = Decimal(self.amount)
-            else:
-                self.amount = int(self.amount)
-        except (ValueError, InvalidOperation):
-            pass
-
-    def __eq__(self, other) -> bool:
-        if not isinstance(other, Quantity):
-            return False
-        return self.amount == other.amount and self.unit == other.unit
-
-    def __str__(self) -> str:
-        return f'{self.amount} {UNIT_MAPPINGS.get(self.unit, REVERSE_UNIT_MAPPING.get(self.unit, self.unit))}'.strip()
-
-    def __repr__(self) -> str:
-        return f'{self.__class__.__name__}(qstr={repr(self._raw)})'
-
-    def __hash__(self) -> int:
-        return hash((self.amount, self.unit))
+from .const import NOTE_PATTERN, QUANTITY_PATTERN
+from .quantity import Quantity
 
 
 class BaseObj:
@@ -79,15 +39,6 @@ class BaseObj:
             return False
         return all(getattr(self, attr) == getattr(other, attr) for attr in ('name', '_parsed_quantity', 'notes'))
 
-    @property
-    def long_str(self) -> str:
-        """Formatted string"""
-        s = str(self.quantity) + ' ' if self.quantity else ''
-        s = f'{s}{self.name}'
-        if self.notes:
-            s += f' ({self.notes})'
-        return s.strip()
-
     def __repr__(self) -> str:
         s = f'{self.__class__.__name__}(raw={self.raw!r}, name={self.name!r}, quantity={self._quantity!r}'
         if self.__class__.supports_notes:
@@ -107,6 +58,56 @@ class BaseObj:
     def __hash__(self) -> int:
         return hash(tuple(getattr(self, attr) for attr in ('name', '_parsed_quantity', 'notes')))
 
+    def __format__(self, format_spec: str) -> str:
+        """
+        Format the string
+
+        %n - Name
+        %q - Quantity
+        %q[<format>] - Quantity as format
+        %c - Notes
+        """
+        if not format_spec:
+            return str(self)
+        s = ''
+        fs = iter(format_spec)
+        c = next(fs)
+        while True:
+            if c == '%':
+                try:
+                    c = next(fs)
+                except StopIteration:
+                    return s
+                match c:
+                    case 'c':
+                        if self.notes:
+                            s += self.notes
+                    case 'n':
+                        s += self.name
+                    case 'q':
+                        try:
+                            c = next(fs)
+                        except StopIteration:
+                            return s + str(self.quantity)
+                        qformat_spec = ''
+                        if c == '[':
+                            try:
+                                while (c := next(fs)) != ']':
+                                    qformat_spec += c
+                            except StopIteration:
+                                return s + f'{self.quantity:{qformat_spec}}' if self.quantity else ''
+                        s += (f'{self.quantity:{qformat_spec}}' if self.quantity else '') + (c if c != ']' else '')
+                    case _:
+                        s += f'%{c}'
+            else:
+                s += c
+            try:
+                c = next(fs)
+            except StopIteration:
+                return s
+            continue
+        return s
+
     @classmethod
     def factory(cls, raw: str):
         """
@@ -132,6 +133,11 @@ class BaseObj:
         name = re.sub(r'\W+$', '', name) or name
         return cls(f'{cls.prefix}{name}', name=name)
 
+    def __radd__(self, other) -> str:
+        if not isinstance(other, str):
+            raise TypeError(f'Cannot add {self} to {other.__class__.__name__}')
+        return f'{other}{self}'
+
 
 class Ingredient(BaseObj):
     """Ingredient"""
@@ -156,6 +162,7 @@ class Timing(BaseObj):
     def __str__(self) -> str:
         return f'{self.name.strip()} {str(self.quantity).strip()}'
 
+    @property
     def long_str(self) -> str:
         return str(self)
 
