@@ -3,9 +3,15 @@
 QUANTITY_PATTERN = r'(?<!\\){(?P<quantity>.*?)}'
 NOTE_PATTERN = r'(?:\((?P<notes>.*)\))?'
 
-UNIT_MAPPINGS = {
+LONG_TO_SHORT_MAPPINGS = {
     'teaspoon': 'tsp',
     'tablespoon': 'tbsp',
+    'teaspoons': 'tsp',
+    'tablespoons': 'tbsp',
+    'cup': 'c',
+    'cups': 'c',
+    'quarts': 'qt',
+    'gallons': 'gal',
     'quart': 'qt',
     'gallon': 'gal',
     'kilo': 'kg',
@@ -14,12 +20,21 @@ UNIT_MAPPINGS = {
     'pound': 'lb',
     'liter': 'l',
     'milliliter': 'ml',
+    'kilos': 'kg',
+    'grams': 'g',
+    'ounces': 'oz',
+    'pounds': 'lb',
+    'liters': 'l',
+    'milliliters': 'ml',
     'hour': 'h',
+    'hours': 'h',
     'minute': 'm',
+    'minutes': 'm',
     'second': 's',
+    'seconds': 's',
 }
 
-REVERSE_UNIT_MAPPING = {v: k for k, v in UNIT_MAPPINGS.items()}
+SHORT_TO_LONG_MAPPINGS = {v: k for k, v in LONG_TO_SHORT_MAPPINGS.items()}
 
 METADATA_MAPPINGS = {
     'source': 'source.name',
