@@ -66,7 +66,7 @@ class Recipe:
                          more of the base objects.
         """
         self._raw = recipe
-        metadata, body = frontmatter.parse(re.sub(r':(?=\S)', ': ', recipe))
+        metadata, body = frontmatter.parse(re.sub(r':(?=[^/\s])', ': ', recipe))
         self.metadata = Metadata(metadata)
         if not body:
             raise ValueError('No body found in recipe!')
@@ -89,11 +89,15 @@ class Recipe:
     def __str__(self) -> str:
         s = str(self.metadata)
         s += 'Ingredients:\n\n'
-        s += '\n'.join(ing.long_str for ing in self.ingredients)
+        s += '\n'.join(
+            (f'{ing:%q[%af %us] %n (%c)}' if ing.notes else f'{ing:%q[%af %us] %n}') for ing in self.ingredients
+        )
         s += '\n' + ('-' * 50) + '\n'
         if self.cookware:
             s += '\nCookware:\n\n'
-            s += '\n'.join(ing.long_str for ing in self.cookware)
+            s += '\n'.join(
+                (f'{cw:%q[%af %us] %n (%c)}' if cw.notes else f'{cw:%q[%af %us] %n}') for cw in self.cookware
+            )
             s += '\n' + ('-' * 50) + '\n'
         s += '\n'
         s += '\n'.join(map(str, self))
@@ -130,7 +134,7 @@ class Step:
         self.cookware: list[Cookware] = list()
         self._sections: list[str | BaseObj] = list()
         self._prefixes: dict[str, type[BaseObj]] = prefixes
-        self.parse(line)
+        self._parse(line)
 
     def __iter__(self):
         yield from self._sections
@@ -141,7 +145,7 @@ class Step:
     def __repr__(self):
         return repr(self._sections)
 
-    def parse(self, line: str):
+    def _parse(self, line: str):
         """
         Parse a line into its component parts
 
